require 'uu/os/rest/dto'
require 'uu/os/uesuri'


# Module Unicorn Universe.
module UU
  # Module Operating System.
  module OS
    # Module Activity Template.
    module ActivityTemplate
      # @see ActivityTemplate#get_attributes
      class ActivityTemplateAttributes < UU::OS::REST::DTO

        # Name of the activity template.
        attr_accessor :name

        # Code of the activity template.
        attr_accessor :code

        # Description of the activity template.
        attr_accessor :description

        # URI of the activity template.
        attr_accessor :uri

        # Type of the activity template.
        # 
        # @see UU::OS::Activity::ActivityType
        attr_accessor :type

        # The default time between the activity creation and its expected completion.
        attr_accessor :notification

        # The duration of the activity template. This parameter makes sense only for activity
        # templates with the type COVER_MEETING or TIME_RESERVATION. For other templates is
        # equal to notification.
        attr_accessor :duration

        # Expiration specifies how long after the expected completion date the activities created
        # according to this template should be automatically terminated. If it is nil, the expiration
        # is disabled.
        attr_accessor :expiration

        # Specifies the level of nesting of the activity template. Root activity templates have
        # this parameter equal to one.
        attr_accessor :level

        # URI of the parent activity template. Nil if the activity template has no parent
        # activity (when it is located directly on the meta artifact).
        attr_accessor :parent_activity_template_uri

        # URI for the artifact or object which is somehow related to the activity template.
        attr_accessor :related_object_uri

        # Specifies whether activities can be created according to this template through
        # the user interface or not.
        attr_accessor :allow_creation_through_ui

        # Specifies whether this activity template is usable as a template for subactivities.
        attr_accessor :allow_as_subactivity_template

        # URI of the activity template which should be used as the default template
        # for subactivities.
        attr_accessor :default_subactivity_template_uri

        # URI of the executive role for the activities created according to this template.
        attr_accessor :executive_role_uri

        # Specifies whether the executive role of the activities created according to this
        # template can be changed.
        attr_accessor :allow_executive_role_change

        # Specifies whether it is allowed to create subactivities of the activities created
        # according to this template.
        attr_accessor :allow_subactivities

        # Specifies whether the activities created according to this template will reserve time
        # in the related users' calendars. This parameter has some value only for activity
        # templates with the type COVER_MEETING or TIME_RESERVATION.
        attr_accessor :block_time_in_calendar

        # Specifies whether the activity template is generic or not.
        attr_accessor :generic

        # Creation time of the activity template.
        attr_accessor :creation_time

        # Time of the last activity template modification.
        attr_accessor :modification_time

        # Version of the activity template.
        attr_accessor :version

        # URI of the activity template's icon.
        attr_accessor :icon_uri

        # URI of the activity template entity type.
        attr_accessor :entity_type_uri

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def type
          attributes[:type]
        end

        def type=(val)
          attributes[:type] = val
        end

        def notification
          attributes[:notification]
        end

        def notification=(val)
          attributes[:notification] = val
        end

        def duration
          attributes[:duration]
        end

        def duration=(val)
          attributes[:duration] = val
        end

        def expiration
          attributes[:expiration]
        end

        def expiration=(val)
          attributes[:expiration] = val
        end

        def level
          attributes[:level]
        end

        def level=(val)
          attributes[:level] = val
        end

        def parent_activity_template_uri
          attributes[:parentActivityTemplateUri]
        end

        def parent_activity_template_uri=(val)
          if val
            attributes[:parentActivityTemplateUri] = UU::OS::UESURI.new(val)
          else
            attributes[:parentActivityTemplateUri] = nil
          end
        end

        def related_object_uri
          attributes[:relatedObjectUri]
        end

        def related_object_uri=(val)
          if val
            attributes[:relatedObjectUri] = UU::OS::UESURI.new(val)
          else
            attributes[:relatedObjectUri] = nil
          end
        end

        def allow_creation_through_ui
          attributes[:allowCreationThroughUi]
        end

        def allow_creation_through_ui=(val)
          attributes[:allowCreationThroughUi] = val
        end

        def allow_as_subactivity_template
          attributes[:allowAsSubactivityTemplate]
        end

        def allow_as_subactivity_template=(val)
          attributes[:allowAsSubactivityTemplate] = val
        end

        def default_subactivity_template_uri
          attributes[:defaultSubactivityTemplateUri]
        end

        def default_subactivity_template_uri=(val)
          if val
            attributes[:defaultSubactivityTemplateUri] = UU::OS::UESURI.new(val)
          else
            attributes[:defaultSubactivityTemplateUri] = nil
          end
        end

        def executive_role_uri
          attributes[:executiveRoleUri]
        end

        def executive_role_uri=(val)
          if val
            attributes[:executiveRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:executiveRoleUri] = nil
          end
        end

        def allow_executive_role_change
          attributes[:allowExecutiveRoleChange]
        end

        def allow_executive_role_change=(val)
          attributes[:allowExecutiveRoleChange] = val
        end

        def allow_subactivities
          attributes[:allowSubactivities]
        end

        def allow_subactivities=(val)
          attributes[:allowSubactivities] = val
        end

        def block_time_in_calendar
          attributes[:blockTimeInCalendar]
        end

        def block_time_in_calendar=(val)
          attributes[:blockTimeInCalendar] = val
        end

        def generic
          attributes[:generic]
        end

        def generic=(val)
          attributes[:generic] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

      end
    end

  end
end
