require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module MetaRole
      class MetaRoleAttributes < UU::OS::REST::DTO

        # Normalized UESURI of the meta role. Never nil.
        attr_accessor :uri

        # Name of the meta role. Never nil.
        attr_accessor :name

        # Code of the meta role. Never nil.
        attr_accessor :code

        # Description of the meta role. Never nil.
        attr_accessor :description

        # Normalized UESURI of the container where the meta role is located. Never nil.
        attr_accessor :location_uri

        # Normalized UESURI of the organizational unit where the meta role is located. Never nil.
        attr_accessor :organizational_unit_uri

        # URI of the company where is the meta model located. Never nil.
        # @deprecated
        attr_accessor :company_uri

        # Normalized UES URI of the meta artifact template. Never nil.
        attr_accessor :meta_artifact_uri

        # Normalized UESURI of the competent role. Never nil.
        attr_accessor :competent_role_uri

        # Security level of the meta role. Never nil.
        #
        # @see UU::OS::Artifact::SecurityLevel
        attr_accessor :security_level

        # Creation stamp of the meta role.
        attr_accessor :creation_stamp

        # Creation time of the meta role.
        attr_accessor :creation_time

        # Modification stamp of the meta role.
        attr_accessor :modification_stamp

        # Modification time of the meta role.
        attr_accessor :modification_time

        # Version of the meta role.
        attr_accessor :version

        # Specifies if it is possible to search for the role created according to
        # the meta role in its territory. Never nil.
        attr_accessor :default_searchable_in_territory

        # URI of the meta role's icon. If nil is set, the meta role uses icon from meta artifact.
        attr_accessor :icon_uri

        # Normalized UESURI of the source meta role from which is meta role copied. Never nil.
        attr_accessor :source_meta_artifact_uri

        # Default name for the artifact created according to the meta role. Never nil.
        attr_accessor :default_name

        # Default code for the artifact created according to the meta role. Never nil.
        attr_accessor :default_code

        # Default security level for the artifact created according to the meta role. Never nil.
        #
        # @see UU::OS::Artifact::SecurityLevel
        attr_accessor :default_security_level

        # Default icon for the artifact created according to the meta role. Never nil.
        attr_accessor :default_icon_uri

        # @deprecated Always returns nil.
        attr_accessor :artifact_type

        # @deprecated Always returns nil.
        attr_accessor :default_artifact_type

        # Indicates whether the primarily displayed content of the meta role is component content.
        attr_accessor :component_content

        # Defines whether the primarily displayed content of a role created according to the meta role is component content. Never nil.
        attr_accessor :default_component_content
        # @deprecated Always returns nil.
        def artifact_type
          nil
        end

        # @deprecated Input value is ignored, nil is always assumed.
        def artifact_type=(val)
        end

        # @deprecated Always returns nil.
        def default_artifact_type
          nil
        end

        # @deprecated Input value is ignored, nil is always assumed.
        def default_artifact_type=(val)
        end

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        # @deprecated
        def company_uri
          attributes[:companyUri]
        end

        # @deprecated
        def company_uri=(val)
          if val
            attributes[:companyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:companyUri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        # @deprecated Use {MetaRoleAttributes#version} instead.
        def revision
          attributes[:version]
        end

        # @deprecated Use {MetaRoleAttributes#version} instead.
        def revision=(val)
          attributes[:version] = val
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def default_searchable_in_territory
          attributes[:defaultSearchableInTerritory]
        end

        def default_searchable_in_territory=(val)
          attributes[:defaultSearchableInTerritory] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def source_meta_artifact_uri
          attributes[:sourceMetaArtifactUri]
        end

        def source_meta_artifact_uri=(val)
          if val
            attributes[:sourceMetaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:sourceMetaArtifactUri] = nil
          end
        end

        def default_name
          attributes[:defaultName]
        end

        def default_name=(val)
          attributes[:defaultName] = val
        end

        def default_code
          attributes[:defaultCode]
        end

        def default_code=(val)
          attributes[:defaultCode] = val
        end

        def default_security_level
          attributes[:defaultSecurityLevel]
        end

        def default_security_level=(val)
          attributes[:defaultSecurityLevel] = val
        end

        def default_icon_uri
          attributes[:defaultIconUri]
        end

        def default_icon_uri=(val)
          if val
            attributes[:defaultIconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:defaultIconUri] = nil
          end
        end

        def component_content
          attributes[:componentContent]
        end

        def component_content=(val)
          attributes[:componentContent] = val
        end

        def default_component_content
          attributes[:defaultComponentContent]
        end

        def default_component_content=(val)
          attributes[:defaultComponentContent] = val
        end

      end
    end

  end

end
