require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS

      module PersonalRole

        class ProfileAttributes < UU::OS::REST::DTO

          # User language. The language is in the ISO 639-1 format, for example: en, cs, es, ru, sk. Never nil.
          attr_accessor :language
          
          # User notifications email. The notifications email, for example: email@email.com.
          attr_accessor :notifications_email
          
          # User notifications rule. The notifications rule, acceptable values: OFF, NEW_ACTIVITIES, UNREAD_ACTIVITIES, (CUSTOM). Never nil.
          attr_accessor :notifications_rule

          # User experimental features enabled. Boolean which enables or disables experimental features. Never nil.
          attr_accessor :experimental_features_enabled 
          
          # User responsive layout enabled. Boolean which enables or disables showing responsive layout.
          attr_accessor :responsive_layout_enabled 
          
          # User responsive content enabled. Boolean which enables or disables showing responsive content.
          attr_accessor :responsive_content_enabled 
          
          # Normalized UESURI of the territory the personal role is contained in. Never nil.
          attr_accessor :my_territory_uri

          # Normalized UESURI of the personal role. Never nil.
          attr_accessor :my_role_uri

          # Normalized UESURI of the personal role's artifact. Never nil.
          attr_accessor :my_artifact_uri

          # Normalized UESURI of the personal role's workspace folder. Never nil.
          attr_accessor :my_workspace_uri

          # Normalized UESURI of the preferred territory. It is the preferred territory of the user identified by
          # the personal role. Nil when no preferred territory is set for the personal role.
          attr_accessor :preferred_territory_uri

          # Normalized UESURI of the access role in the preferred territory. It is the access role of the user
          # identified by the personal role. Nil when no preferred territory is set for the personal role.
          attr_accessor :preferred_access_role_uri

          # Normalized UESURI of the preferred role in the preferred territory. Those are the preferred territory
          # and the preferred role of the user identified by the personal role. Nil when no preferred territory
          # is set for the personal role or no preferred role is set in the territory.
          attr_accessor :preferred_role_uri

          # Normalized UESURI of the preferred role's artifact in the preferred territory. Those are the preferred
          # territory and the preferred role of the user identified by the personal role. Nil when no preferred
          # territory is set for the personal role or no preferred role is set in the territory.
          attr_accessor :preferred_artifact_uri

          # Normalized UESURI of the preferred role's workspace folder in the preferred territory. Those are the
          # preferred territory and the preferred role of the user identified by the personal role. Nil when no
          # preferred territory is set for the personal role or no preferred role is set in the territory.
          attr_accessor :preferred_workspace_uri
          
          # Location of user bookmarks. The location is a Folder or Organizational Unit of the same territory as the Personal Role, or it is not set at all.
          attr_accessor :bookmarks_location_uri
          
          # Specifies whether the user global login is enabled. Never nil.
          attr_accessor :global_login_enabled
          
          # List of portlets displayed in the portlet area. The value is an array of portlet codes defined in {UU::OS::PersonalRole::PersonalRolePortlet PersonalRolePortlet}. An empty position with no portlet is specified by a nil value. Example: ["NAVIGATION", "NEW_ACTIVITIES", nil, "TABLE_OF_CONTENTS"]. The maximum allowed number of portlets (array size) is 5. Never nil.
          attr_accessor :portlets
          
          # Specifies whether the portlet area is displayed. Never nil.
          attr_accessor :portlets_mode
          
          # Specifies whether the portlet area is displayed on mobile devices. If set to DEFAULT, then the portlet area will be displayed on mobile devices according to the portlets_mode.
          attr_accessor :portlets_mobile_mode
         
          # Enables or disables the automatic saving of links to artifacts in the navigator. Setting this attribute may not have any effect if the UC for adding bookmark to navigator is not available for given personal role.
          attr_accessor :bookmarks_to_navigator

          def language 
            attributes[:language]
          end

          def language=(val) 
            attributes[:language] = val
          end
          
          def notifications_email 
            attributes[:notificationsEmail]
          end

          def notifications_email=(val) 
            attributes[:notificationsEmail] = val
          end
          
          def notifications_rule 
            attributes[:notificationsRule]
          end

          def notifications_rule=(val) 
            attributes[:notificationsRule] = val
          end
          
          def experimental_features_enabled 
            attributes[:experimentalFeaturesEnabled]
          end

          def experimental_features_enabled=(val) 
            attributes[:experimentalFeaturesEnabled] = val
          end
          
          def responsive_layout_enabled
            attributes[:responsiveLayoutEnabled]
          end
          
          def responsive_layout_enabled=(val)
            attributes[:responsiveLayoutEnabled] = val
          end
          
          def responsive_content_enabled
            attributes[:responsiveContentEnabled]
          end
          
          def responsive_content_enabled=(val)
            attributes[:responsiveContentEnabled] = val
          end

          def my_territory_uri 
            attributes[:myTerritoryUri]
          end

          def my_territory_uri=(val) 
            if val
              attributes[:myTerritoryUri] = UU::OS::UESURI.new(val)
            else
              attributes[:myTerritoryUri] = nil
            end
          end

          def my_role_uri 
            attributes[:myRoleUri]
          end

          def my_role_uri=(val) 
            if val
              attributes[:myRoleUri] = UU::OS::UESURI.new(val)
            else
              attributes[:myRoleUri] = nil
            end
          end

          def my_artifact_uri 
            attributes[:myArtifactUri]
          end

          def my_artifact_uri=(val) 
            if val
              attributes[:myArtifactUri] = UU::OS::UESURI.new(val)
            else
              attributes[:myArtifactUri] = nil
            end
          end

          def my_workspace_uri 
            attributes[:myWorkspaceUri]
          end

          def my_workspace_uri=(val) 
            if val
              attributes[:myWorkspaceUri] = UU::OS::UESURI.new(val)
            else
              attributes[:myWorkspaceUri] = nil
            end
          end

          def preferred_territory_uri 
            attributes[:preferredTerritoryUri]
          end

          def preferred_territory_uri=(val) 
            if val
              attributes[:preferredTerritoryUri] = UU::OS::UESURI.new(val)
            else
              attributes[:preferredTerritoryUri] = nil
            end
          end

          def preferred_access_role_uri 
            attributes[:preferredAccessRoleUri]
          end

          def preferred_access_role_uri=(val) 
            if val
              attributes[:preferredAccessRoleUri] = UU::OS::UESURI.new(val)
            else
              attributes[:preferredAccessRoleUri] = nil
            end
          end

          def preferred_role_uri 
            attributes[:preferredRoleUri]
          end

          def preferred_role_uri=(val) 
            if val
              attributes[:preferredRoleUri] = UU::OS::UESURI.new(val)
            else
              attributes[:preferredRoleUri] = nil
            end
          end

          def preferred_artifact_uri 
            attributes[:preferredArtifactUri]
          end

          def preferred_artifact_uri=(val) 
            if val
              attributes[:preferredArtifactUri] = UU::OS::UESURI.new(val)
            else
              attributes[:preferredArtifactUri] = nil
            end
          end

          def preferred_workspace_uri 
            attributes[:preferredWorkspaceUri]
          end

          def preferred_workspace_uri=(val) 
            if val
              attributes[:preferredWorkspaceUri] = UU::OS::UESURI.new(val)
            else
              attributes[:preferredWorkspaceUri] = nil
            end
          end

          def bookmarks_location_uri 
            attributes[:bookmarksLocationUri]
          end

          def bookmarks_location_uri=(val) 
            if val
              attributes[:bookmarksLocationUri] = UU::OS::UESURI.new(val)
            else
              attributes[:bookmarksLocationUri] = nil
            end
          end

          def global_login_enabled 
            attributes[:globalLoginEnabled]
          end

          def global_login_enabled=(val) 
            attributes[:globalLoginEnabled] = val
          end
          
          def bookmarks_to_navigator 
            attributes[:bookmarksToNavigator]
          end
          
          def bookmarks_to_navigator=(val) 
            attributes[:bookmarksToNavigator] = val
          end

          def portlets 
            attributes[:portlets]
          end

          def portlets=(val) 
            attributes[:portlets] = val
          end
          
          def portlets_mode 
            attributes[:portletsMode]
          end

          def portlets_mode=(val) 
            attributes[:portletsMode] = val
          end
          
          def portlets_mobile_mode 
            attributes[:portletsMobileMode]
          end

          def portlets_mobile_mode=(val) 
            attributes[:portletsMobileMode] = val
          end          

        end
      end
    end
end
