require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
      module Property

        class PropertyCreate < UU::OS::REST::DTO

          # Name of the new property. When nil is set and the templateUri parameter is not nil, the name is
          # taken from the template tName. When the template does not define a tName, the create command fails.
          # When nil is set the template has to be specified (the template_uri parameter can't be nil),
          # otherwise the create command fails.
          attr_accessor :name

          # Code of the new property. When nil is set, the code is generated automatically using the system
          # sequence. The code must be unique in a given artifact, otherwise the create command fails.
          attr_accessor :code

          # Description of the new property. When nil is set, the description is taken from the template
          # tDescription. When the template does not define a tDescription, it is left empty.
          attr_accessor :description

          # UESURI of the new property template. The template determines the type of the new property. When
          # nil is set, the template is determined by the type attribute (which cannot be nil in that case).
          attr_accessor :template_uri

          # Specifies the type of the new property. When nil is set, the property type is determined by the
          # template (templateUri attribute, which cannot be nil in that case).
          attr_accessor :type

          # The value of the new property. Passed object type has to correspond to the type of the new property,
          # for details. When nil is set, the new property has no value. If the property value is set as file, is 
          # highly recommended to open file in binary mode, for example: File.open("file_name.txt", "rb").
          attr_accessor :value

          def name 
            attributes[:name]
          end

          def name=(val) 
            attributes[:name] = val
          end

          def code 
            attributes[:code]
          end

          def code=(val) 
            attributes[:code] = val
          end

          def description 
            attributes[:description]
          end

          def description=(val) 
            attributes[:description] = val
          end

          def template_uri 
            attributes[:templateUri]
          end

          def template_uri=(val) 
            if val
              attributes[:templateUri] = UU::OS::UESURI.new(val)
            else
              attributes[:templateUri] = nil
            end
          end

          def type 
            attributes[:type]
          end

          def type=(val) 
            attributes[:type] = val
          end

          def value 
            attributes[:value]
          end

          def value=(val) 
            attributes[:value] = val
          end

        end

      end
    end
end
